==> imuikit-1.0.4.20171106_2-sources.jar: com/xdja/im/uikit/ui/view/ViewCustomRecItem.java <==
package com.xdja.im.uikit.ui.view;

import android.support.annotation.NonNull;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.google.gson.Gson;
import com.xdja.im.core.config.ConstDef;
import com.xdja.im.core.model.account.AccountBean;
import com.xdja.im.core.model.custom.CustomMsgInfo;
import com.xdja.im.core.model.message.TalkMessageBean;
import com.xdja.im.core.proxy.IMUiKitProxyImpl;
import com.xdja.im.uikit.R;
import com.xdja.im.uikit.action.options.ImOption;
import com.xdja.im.uikit.constans.Constant;
import com.xdja.im.uikit.ui.dialog.BaseListDialog;

import java.util.ArrayList;
import java.util.List;

import rx.Subscriber;


/**
 * @Package: com.xdja.im.uikit.ui
 * @Author: xdjaxa
 * @Creation: 2017-04-20 14:45
 * @Version V1.0
 * @Description:自定义聊天类型
 */
public class ViewCustomRecItem extends BaseChatItem {
    private ImageView imgCustomType;
    private TextView tvCustominfo;
    private LinearLayout linearLayout;
    private CustomMsgInfo customMsgInfo;
    private ImageView missedMsgIv;
    /**
     * 发送者名称
     */
    private TextView senderNameTextView;
    private Gson gson = new Gson();

    private static final String SINGLE_VOICE = "single_voice";
    private static final String SINGLE_CALLBACK = "single_video";
    private static final String GROUP_VOICE = "group_voice";

    @Override
    protected int getLayoutRes() {
        return R.layout.im_uikit_item_chat_receive_custom;
    }


    @Override
    protected void injectView() {
        super.injectView();
        senderNameTextView = (TextView) findViewById(R.id.txt_chat_senderName);
        imgCustomType = (ImageView) findViewById(R.id.img_custom_rec);
        tvCustominfo = (TextView) findViewById(R.id.tv_custom_info);
        missedMsgIv = (ImageView) findViewById(R.id.img_new_flag);
        linearLayout = (LinearLayout) findViewById(R.id.layout_message_container);
        linearLayout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                final CustomMsgInfo customMsgInfo = gson.fromJson(dataSource.getContent(), CustomMsgInfo.class);
                int type = customMsgInfo.getType();
                if (customMsgInfo.getState() == ConstDef.SENDER_CANCEL
                        || customMsgInfo.getState() == ConstDef.NO_RESPONSE) {
                    getPresenter().sendReadReceipt(dataSource);
                }
                switch (type) {
                    case ConstDef.CALLBACK_P2P:
                        IMUiKitProxyImpl.getInstance().startCallback(customMsgInfo.getFromAtNo());
                        break;
                    case ConstDef.CALLBACK_P2G:
                        break;
                    case ConstDef.MEETING_P2P:
                        IMUiKitProxyImpl.getInstance().startVoice(customMsgInfo.getFromAtNo(), ConstDef.CHAT_TYPE_P2P);
                        if (missedMsgIv != null) {
                            missedMsgIv.setVisibility(View.GONE);
                        }
                        break;
                    case ConstDef.MEETING_P2G:
                        IMUiKitProxyImpl.getInstance().startVoice(customMsgInfo.getToAtNo(), ConstDef.CHAT_TYPE_P2G);
                        if (missedMsgIv != null) {
                            missedMsgIv.setVisibility(View.GONE);
                        }
                        break;
                }
            }
        });
        linearLayout.setOnLongClickListener(new View.OnLongClickListener() {
            @Override
            public boolean onLongClick(View v) {
                List<ImOption> data = new ArrayList<>();
                data.add(mImOptions.get(0));
                mPopDialog.addData(data);
                mPopDialog.show(curPosition);
                return true;
            }
        });
        mPopDialog.setOnItemClickListener(new BaseListDialog.onItemClickListener() {
            @Override
            public void onItemClick(View view, ImOption option, int itemPosition) {
                mPopDialog.dismiss();
                switch (option.getOptionType()) {
                    case Constant.ITEM_CHAT_DELETE:  //删除消息
                        getPresenter().deleteItem(itemPosition);
                        break;
                }
            }
        });
    }

    @Override
    public void bindDataSource(int position, @NonNull TalkMessageBean dataSource) {
        super.bindDataSource(position, dataSource);

        if (dataSource.getMessageType() == ConstDef.CHAT_TYPE_P2G) {
            getPresenter().getAccount(dataSource.getFrom(), ConstDef.CHAT_TYPE_P2P,
                    new Subscriber<AccountBean>() {
                        @Override
                        public void onCompleted() {

                        }

                        @Override
                        public void onError(Throwable e) {

                        }

                        @Override
                        public void onNext(AccountBean accountBean) {
                            senderNameTextView.setText(accountBean.getDisplayName());
                        }
                    });
        } else {
            senderNameTextView.setVisibility(View.GONE);
        }
        customMsgInfo = gson.fromJson(dataSource.getContent(), CustomMsgInfo.class);
        int type = customMsgInfo.getType();
        int state = customMsgInfo.getState();
        boolean isRecalled = (dataSource.getMessageState() == ConstDef.STATE_READED);
        long amountOfTime = customMsgInfo.getAmountOfTime();
        boolean isVideoCallback = (type == ConstDef.CALLBACK_P2P || type == ConstDef.CALLBACK_P2G);
        String content = "";
        if (state == ConstDef.SENDER_CANCEL) {
            if (isVideoCallback) {
                content = "未接视频回传";
            } else {
                content = "未接语音通话";
            }
        } else if (state == ConstDef.NO_RESPONSE) {
            if (isVideoCallback) {
                content = "未接视频回传";
            } else {
                if (type == ConstDef.MEETING_P2P) {
                    content = "未接语音通话";
                } else {
                    content = "未接语音会议";
                }
            }
        } else if (state == ConstDef.RECER_CANCEL) {
            content = "已拒绝";
        } else if (state == ConstDef.OVER) {
            content = buildMsgContent(type, amountOfTime);
        }
        if (isVideoCallback) {
            imgCustomType.setBackgroundResource(R.mipmap.im_uikit_icon_custom_callback);
        } else {
            imgCustomType.setBackgroundResource(R.mipmap.im_uikit_icon_custom_meeting);
        }
        tvCustominfo.setText(content);
        if (!isRecalled && (state == ConstDef.SENDER_CANCEL || state == ConstDef.NO_RESPONSE)) {
            missedMsgIv.setVisibility(View.VISIBLE);
        } else {
            missedMsgIv.setVisibility(View.GONE);
        }
    }

    private String buildMsgContent(int type, long amountOfTime) {
        StringBuilder builder = new StringBuilder();
        switch (type) {
            case ConstDef.CALLBACK_P2P:
            case ConstDef.CALLBACK_P2G:
                builder.append("视频回传");
                builder.append(" " + getFormatTime(amountOfTime));
                break;
            case ConstDef.MEETING_P2P:
                builder.append("语音通话");
                builder.append(" " + getFormatTime(amountOfTime));
                break;
            case ConstDef.MEETING_P2G:
                builder.append("语音会议");
                break;
        }
        return builder.toString();
    }

    private String getFormatTime(long amountOfTime) {
        long hour = amountOfTime / 3600;
        long min = amountOfTime / 60 % 60;
        long second = amountOfTime % 60;
        String hourStr = hour < 10 ? "0" + hour : "" + hour;
        String minStr = min < 10 ? "0" + min : "" + min;
        String secondStr = second < 10 ? "0" + second : "" + second;
        return hourStr + ":" + minStr + ":" + secondStr;
    }
}

==> imuikit-1.0.5.20171220_5-sources.jar: com/xdja/im/uikit/ui/view/ViewCustomRecItem.java <==
package com.xdja.im.uikit.ui.view;

import android.support.annotation.NonNull;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.google.gson.Gson;
import com.xdja.im.core.config.ConstDef;
import com.xdja.im.core.model.account.AccountBean;
import com.xdja.im.core.model.custom.CustomMsgInfo;
import com.xdja.im.core.model.message.TalkMessageBean;
import com.xdja.im.core.proxy.IMUiKitProxyImpl;
import com.xdja.im.uikit.R;
import com.xdja.im.uikit.action.options.ImOption;
import com.xdja.im.uikit.constans.Constant;
import com.xdja.im.uikit.ui.dialog.BaseListDialog;

import java.util.ArrayList;
import java.util.List;

import rx.Subscriber;


/**
 * @Package: com.xdja.im.uikit.ui
 * @Author: xdjaxa
 * @Creation: 2017-04-20 14:45
 * @Version V1.0
 * @Description:自定义聊天类型
 */
public class ViewCustomRecItem extends BaseChatItem {
    private ImageView imgCustomType;
    private TextView tvCustominfo;
    private LinearLayout linearLayout;
    private CustomMsgInfo customMsgInfo;
    private ImageView missedMsgIv;
    /**
     * 发送者名称
     */
    private TextView senderNameTextView;
    private Gson gson = new Gson();

    private static final String SINGLE_VOICE = "single_voice";
    private static final String SINGLE_CALLBACK = "single_video";
    private static final String GROUP_VOICE = "group_voice";

    @Override
    protected int getLayoutRes() {
        return R.layout.im_uikit_item_chat_receive_custom;
    }


    @Override
    protected void injectView() {
        super.injectView();
        senderNameTextView = (TextView) findViewById(R.id.txt_chat_senderName);
        imgCustomType = (ImageView) findViewById(R.id.img_custom_rec);
        tvCustominfo = (TextView) findViewById(R.id.tv_custom_info);
        missedMsgIv = (ImageView) findViewById(R.id.img_new_flag);
        linearLayout = (LinearLayout) findViewById(R.id.layout_message_container);
        linearLayout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                final CustomMsgInfo customMsgInfo = gson.fromJson(dataSource.getContent(), CustomMsgInfo.class);
                int type = customMsgInfo.getType();
                if (customMsgInfo.getState() == ConstDef.SENDER_CANCEL
                        || customMsgInfo.getState() == ConstDef.NO_RESPONSE) {
                    getPresenter().sendReadReceipt(dataSource);
                }
                switch (type) {
                    case ConstDef.CALLBACK_P2P:
                    case ConstDef.VIDEO_CHAT:
                        IMUiKitProxyImpl.getInstance().startCallback(customMsgInfo.getFromAtNo());
                        break;
                    case ConstDef.CALLBACK_P2G:
                        break;
                    case ConstDef.MEETING_P2P:
                        IMUiKitProxyImpl.getInstance().startVoice(customMsgInfo.getFromAtNo(), ConstDef.CHAT_TYPE_P2P);
                        if (missedMsgIv != null) {
                            missedMsgIv.setVisibility(View.GONE);
                        }
                        break;
                    case ConstDef.MEETING_P2G:
                        IMUiKitProxyImpl.getInstance().startVoice(customMsgInfo.getToAtNo(), ConstDef.CHAT_TYPE_P2G);
                        if (missedMsgIv != null) {
                            missedMsgIv.setVisibility(View.GONE);
                        }
                        break;
                }
            }
        });
        linearLayout.setOnLongClickListener(new View.OnLongClickListener() {
            @Override
            public boolean onLongClick(View v) {
                List<ImOption> data = new ArrayList<>();
                data.add(mImOptions.get(0));
                mPopDialog.addData(data);
                mPopDialog.show(curPosition);
                return true;
            }
        });
        mPopDialog.setOnItemClickListener(new BaseListDialog.onItemClickListener() {
            @Override
            public void onItemClick(View view, ImOption option, int itemPosition) {
                mPopDialog.dismiss();
                switch (option.getOptionType()) {
                    case Constant.ITEM_CHAT_DELETE:  //删除消息
                        getPresenter().deleteItem(itemPosition);
                        break;
                }
            }
        });
    }

    @Override
    public void bindDataSource(int position, @NonNull TalkMessageBean dataSource) {
        super.bindDataSource(position, dataSource);

        if (dataSource.getMessageType() == ConstDef.MSG_TYPE_CUSTOM && dataSource.isGroupMsg()) {
            getPresenter().getAccount(dataSource.getFrom(), ConstDef.CHAT_TYPE_P2P,
                    new Subscriber<AccountBean>() {
                        @Override
                        public void onCompleted() {

                        }

                        @Override
                        public void onError(Throwable e) {

                        }

                        @Override
                        public void onNext(AccountBean accountBean) {
                            senderNameTextView.setText(accountBean.getDisplayName());
                        }
                    });
        } else {
            senderNameTextView.setVisibility(View.GONE);
        }
        customMsgInfo = gson.fromJson(dataSource.getContent(), CustomMsgInfo.class);
        int type = customMsgInfo.getType();
        int state = customMsgInfo.getState();
        boolean isRecalled = (dataSource.getMessageState() == ConstDef.STATE_READED);
        long amountOfTime = customMsgInfo.getAmountOfTime();
        boolean isVideoCallback = (type == ConstDef.CALLBACK_P2P || type == ConstDef.CALLBACK_P2G || type == ConstDef.VIDEO_CHAT);
        String content = "";
        if (state == ConstDef.SENDER_CANCEL) {
            if (isVideoCallback) {
                if(type == ConstDef.VIDEO_CHAT) {
                    content = "未接视频通话";
                } else {
                    content = "未接视频回传";
                }
            } else {
                content = "未接语音通话";
            }
        } else if (state == ConstDef.NO_RESPONSE) {
            if (isVideoCallback) {
                if(type == ConstDef.VIDEO_CHAT) {
                    content = "未接视频通话";
                } else {
                    content = "未接视频回传";
                }
            } else {
                if (type == ConstDef.MEETING_P2P) {
                    content = "未接语音通话";
                } else {
                    content = "未接语音会议";
                }
            }
        } else if (state == ConstDef.RECER_CANCEL) {
            content = "已拒绝";
        } else if (state == ConstDef.OVER) {
            content = buildMsgContent(type, amountOfTime);
        }
        if (isVideoCallback) {
            imgCustomType.setBackgroundResource(R.mipmap.im_uikit_icon_custom_callback_receiver);
        } else {
            imgCustomType.setBackgroundResource(R.mipmap.im_uikit_icon_custom_meeting_receiver);
        }
        tvCustominfo.setText(content);
        if (!isRecalled && (state == ConstDef.SENDER_CANCEL || state == ConstDef.NO_RESPONSE)) {
            missedMsgIv.setVisibility(View.VISIBLE);
        } else {
            missedMsgIv.setVisibility(View.GONE);
        }
    }

    private String buildMsgContent(int type, long amountOfTime) {
        StringBuilder builder = new StringBuilder();
        switch (type) {
            case ConstDef.CALLBACK_P2P:
            case ConstDef.CALLBACK_P2G:
                builder.append("视频回传");
                builder.append(" " + getFormatTime(amountOfTime));
                break;
            case ConstDef.VIDEO_CHAT:
                builder.append("视频通话");
                builder.append(" " + getFormatTime(amountOfTime));
                break;
            case ConstDef.MEETING_P2P:
                builder.append("语音通话");
                builder.append(" " + getFormatTime(amountOfTime));
                break;
            case ConstDef.MEETING_P2G:
                builder.append("语音会议");
                break;
        }
        return builder.toString();
    }

    private String getFormatTime(long amountOfTime) {
        long hour = amountOfTime / 3600;
        long min = amountOfTime / 60 % 60;
        long second = amountOfTime % 60;
        String hourStr = hour < 10 ? "0" + hour : "" + hour;
        String minStr = min < 10 ? "0" + min : "" + min;
        String secondStr = second < 10 ? "0" + second : "" + second;
        return hourStr + ":" + minStr + ":" + secondStr;
    }
}
